==> ejc-probid-api-3.0.0-20220715.093529-11-sources.jar: com/ejianc/business/pay/vo/PayBackRecordVO.java <==
package com.ejianc.business.pay.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;
import java.util.Date;


/**
 * 保证金缴纳-退还记录实体
 *
 * @author generator
 */
public class PayBackRecordVO extends BaseVO {
	private static final long serialVersionUID = 7256773653304372497L;

	private Long employeeId; // 经办人id
	private String employeeName; // 经办人名称
	private Date commitDate; // 提交日期
	private String commitUserName; // 提交人名称
	private String commitUserCode; // 提交人账号
	private Date effectiveDate; // 生效日期
	private String billCode; // 单据编码
	private String billName; // 单据名称
	private String billType; // 单据类型
	private Integer billState; // 单据状态
	private String billStateName; // 单据状态名称
	private Long sourceBondBackId; // 保证金退还id
	private String sourceBillCode; // 保证金退还编码
	private String sourceBillName; // 保证金退还名称
	private BigDecimal backMny; // 退还金额
	private Date backDate; // 退还日期
	private String backMemo; // 说明
	private Long bondPayId; // 保证金缴纳id


	public Long getEmployeeId() {
		return employeeId;
	}

	public void setEmployeeId(Long employeeId) {
		this.employeeId = employeeId;
	}

	public String getEmployeeName() {
		return employeeName;
	}

	public void setEmployeeName(String employeeName) {
		this.employeeName = employeeName;
	}

	public Date getCommitDate() {
		return commitDate;
	}

	public void setCommitDate(Date commitDate) {
		this.commitDate = commitDate;
	}

	public String getCommitUserName() {
		return commitUserName;
	}

	public void setCommitUserName(String commitUserName) {
		this.commitUserName = commitUserName;
	}

	public String getCommitUserCode() {
		return commitUserCode;
	}

	public void setCommitUserCode(String commitUserCode) {
		this.commitUserCode = commitUserCode;
	}

	public Date getEffectiveDate() {
		return effectiveDate;
	}

	public void setEffectiveDate(Date effectiveDate) {
		this.effectiveDate = effectiveDate;
	}

	public String getBillCode() {
		return billCode;
	}

	public void setBillCode(String billCode) {
		this.billCode = billCode;
	}

	public String getBillName() {
		return billName;
	}

	public void setBillName(String billName) {
		this.billName = billName;
	}

	public String getBillType() {
		return billType;
	}

	public void setBillType(String billType) {
		this.billType = billType;
	}

	public Integer getBillState() {
		return billState;
	}

	public void setBillState(Integer billState) {
		this.billState = billState;
	}

	public String getBillStateName() {
		return billStateName;
	}

	public void setBillStateName(String billStateName) {
		this.billStateName = billStateName;
	}

	public Long getSourceBondBackId() {
		return sourceBondBackId;
	}

	public void setSourceBondBackId(Long sourceBondBackId) {
		this.sourceBondBackId = sourceBondBackId;
	}

	public String getSourceBillCode() {
		return sourceBillCode;
	}

	public void setSourceBillCode(String sourceBillCode) {
		this.sourceBillCode = sourceBillCode;
	}

	public String getSourceBillName() {
		return sourceBillName;
	}

	public void setSourceBillName(String sourceBillName) {
		this.sourceBillName = sourceBillName;
	}

	public BigDecimal getBackMny() {
		return backMny;
	}

	public void setBackMny(BigDecimal backMny) {
		this.backMny = backMny;
	}

	public Date getBackDate() {
		return backDate;
	}

	public void setBackDate(Date backDate) {
		this.backDate = backDate;
	}

	public String getBackMemo() {
		return backMemo;
	}

	public void setBackMemo(String backMemo) {
		this.backMemo = backMemo;
	}

	public Long getBondPayId() {
		return bondPayId;
	}

	public void setBondPayId(Long bondPayId) {
		this.bondPayId = bondPayId;
	}

}

==> ejc-probid-api-3.0.0-20230216.072204-86-sources.jar: com/ejianc/business/pay/vo/PayBackRecordVO.java <==
package com.ejianc.business.pay.vo;

import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.math.BigDecimal;
import java.util.Date;


/**
 * 保证金缴纳-退还记录实体
 *
 * @author generator
 */
public class PayBackRecordVO extends BaseVO {
	private static final long serialVersionUID = 7256773653304372497L;

	private Long sourceEmployeeId; // 经办人id
	private String sourceEmployeeName; // 经办人名称
	private Date commitDate; // 提交日期
	private String commitUserName; // 提交人名称
	private String commitUserCode; // 提交人账号
	private Date effectiveDate; // 生效日期
	private String billCode; // 单据编码
	private String billName; // 单据名称
	private String billType; // 单据类型
	private Integer billState; // 单据状态
	private String billStateName; // 单据状态名称
	private Long sourceBondBackId; // 保证金退还id
	private String sourceBillCode; // 保证金退还编码
	private String sourceBillName; // 保证金退还名称
	private BigDecimal sourceBackMny; // 退还金额
	@JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
	private Date sourceBackDate; // 退还日期
	private String sourceBackMemo; // 说明
	private Long bondPayId; // 保证金缴纳id


	public Long getSourceEmployeeId() {
		return sourceEmployeeId;
	}

	public void setSourceEmployeeId(Long sourceEmployeeId) {
		this.sourceEmployeeId = sourceEmployeeId;
	}

	public String getSourceEmployeeName() {
		return sourceEmployeeName;
	}

	public void setSourceEmployeeName(String sourceEmployeeName) {
		this.sourceEmployeeName = sourceEmployeeName;
	}

	public Date getCommitDate() {
		return commitDate;
	}

	public void setCommitDate(Date commitDate) {
		this.commitDate = commitDate;
	}

	public String getCommitUserName() {
		return commitUserName;
	}

	public void setCommitUserName(String commitUserName) {
		this.commitUserName = commitUserName;
	}

	public String getCommitUserCode() {
		return commitUserCode;
	}

	public void setCommitUserCode(String commitUserCode) {
		this.commitUserCode = commitUserCode;
	}

	public Date getEffectiveDate() {
		return effectiveDate;
	}

	public void setEffectiveDate(Date effectiveDate) {
		this.effectiveDate = effectiveDate;
	}

	public String getBillCode() {
		return billCode;
	}

	public void setBillCode(String billCode) {
		this.billCode = billCode;
	}

	public String getBillName() {
		return billName;
	}

	public void setBillName(String billName) {
		this.billName = billName;
	}

	public String getBillType() {
		return billType;
	}

	public void setBillType(String billType) {
		this.billType = billType;
	}

	public Integer getBillState() {
		return billState;
	}

	public void setBillState(Integer billState) {
		this.billState = billState;
	}

	public String getBillStateName() {
		return billStateName;
	}

	public void setBillStateName(String billStateName) {
		this.billStateName = billStateName;
	}

	public Long getSourceBondBackId() {
		return sourceBondBackId;
	}

	public void setSourceBondBackId(Long sourceBondBackId) {
		this.sourceBondBackId = sourceBondBackId;
	}

	public String getSourceBillCode() {
		return sourceBillCode;
	}

	public void setSourceBillCode(String sourceBillCode) {
		this.sourceBillCode = sourceBillCode;
	}

	public String getSourceBillName() {
		return sourceBillName;
	}

	public void setSourceBillName(String sourceBillName) {
		this.sourceBillName = sourceBillName;
	}

	public BigDecimal getSourceBackMny() {
		return sourceBackMny;
	}

	public void setSourceBackMny(BigDecimal sourceBackMny) {
		this.sourceBackMny = sourceBackMny;
	}

	public Date getSourceBackDate() {
		return sourceBackDate;
	}

	public void setSourceBackDate(Date sourceBackDate) {
		this.sourceBackDate = sourceBackDate;
	}

	public String getSourceBackMemo() {
		return sourceBackMemo;
	}

	public void setSourceBackMemo(String sourceBackMemo) {
		this.sourceBackMemo = sourceBackMemo;
	}

	public Long getBondPayId() {
		return bondPayId;
	}

	public void setBondPayId(Long bondPayId) {
		this.bondPayId = bondPayId;
	}

}
